==> jersey-server-1.1.4.1-sources.jar: com/sun/jersey/server/impl/uri/rules/ResourceObjectRule.java <==
/*
 *
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 * 
 * Copyright 1997-2007 Sun Microsystems, Inc. All rights reserved.
 * 
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License. You can obtain
 * a copy of the License at https://jersey.dev.java.net/CDDL+GPL.html
 * or jersey/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 * 
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at jersey/legal/LICENSE.txt.
 * Sun designates this particular file as subject to the "Classpath" exception
 * as provided by Sun in the GPL Version 2 section of the License file that
 * accompanied this code.  If applicable, add the following below the License
 * Header, with the fields enclosed by brackets [] replaced by your own
 * identifying information: "Portions Copyrighted [year]
 * [name of copyright owner]"
 * 
 * Contributor(s):
 * 
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package com.sun.jersey.server.impl.uri.rules;

import com.sun.jersey.api.uri.UriTemplate;
import com.sun.jersey.spi.uri.rules.UriRule;
import com.sun.jersey.spi.uri.rules.UriRuleContext;
import com.sun.jersey.server.probes.UriRuleProbeProvider;
import java.util.Iterator;

/**
 * The rule for accepting a resource object.
 * 
 * @author Paul.Sandoz@Sun.Com
 */
public final class ResourceObjectRule extends BaseRule {

    private final Object resourceObject;
    
    public ResourceObjectRule(UriTemplate template, Object resourceObject) {
        super(template);
        this.resourceObject = resourceObject;
    }
    
    public boolean accept(CharSequence path, Object resource, UriRuleContext context) {
        // Set the template values
        pushMatch(context);

        context.pushResource(resourceObject);

        UriRuleProbeProvider.ruleAccept(ResourceObjectRule.class.getSimpleName(), path,
                resourceObject);

        // Match sub-rules on the resource class
        final Iterator<UriRule> matches = context.getRules(resourceObject.getClass()).
                match(path, context);
        while (matches.hasNext())
            if (matches.next().accept(path, resourceObject, context))
                return true;
        
        return false;
    }
}

==> jersey-server-1.1.5-sources.jar: com/sun/jersey/server/impl/uri/rules/ResourceObjectRule.java <==
/*
 *
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 * 
 * Copyright 1997-2007 Sun Microsystems, Inc. All rights reserved.
 * 
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License. You can obtain
 * a copy of the License at https://jersey.dev.java.net/CDDL+GPL.html
 * or jersey/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 * 
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at jersey/legal/LICENSE.txt.
 * Sun designates this particular file as subject to the "Classpath" exception
 * as provided by Sun in the GPL Version 2 section of the License file that
 * accompanied this code.  If applicable, add the following below the License
 * Header, with the fields enclosed by brackets [] replaced by your own
 * identifying information: "Portions Copyrighted [year]
 * [name of copyright owner]"
 * 
 * Contributor(s):
 * 
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package com.sun.jersey.server.impl.uri.rules;

import com.sun.jersey.api.uri.UriTemplate;
import com.sun.jersey.core.reflection.ReflectionHelper;
import com.sun.jersey.spi.uri.rules.UriRule;
import com.sun.jersey.spi.uri.rules.UriRuleContext;
import com.sun.jersey.server.probes.UriRuleProbeProvider;
import java.util.Iterator;

/**
 * The rule for accepting a resource object.
 * 
 * @author Paul.Sandoz@Sun.Com
 */
public final class ResourceObjectRule extends BaseRule {

    private final Object resourceObject;
    
    public ResourceObjectRule(UriTemplate template, Object resourceObject) {
        super(template);
        this.resourceObject = resourceObject;
    }
    
    public boolean accept(CharSequence path, Object resource, UriRuleContext context) {
        // Set the template values
        pushMatch(context);

        if (context.isTracingEnabled()) {
            context.trace(String.format("accept resource: \"%s\" -> @Path(\"%s\") %s",
                    context.getUriInfo().getMatchedURIs().get(0),
                    getTemplate().getTemplate(),
                    ReflectionHelper.objectToString(resourceObject)));
        }

        context.pushResource(resourceObject);

        UriRuleProbeProvider.ruleAccept(ResourceObjectRule.class.getSimpleName(), path,
                resourceObject);

        // Match sub-rules on the resource class
        final Iterator<UriRule> matches = context.getRules(resourceObject.getClass()).
                match(path, context);
        while (matches.hasNext())
            if (matches.next().accept(path, resourceObject, context))
                return true;
        
        return false;
    }
}
